Authors
=======

* Patrick Parente Nasser - `www.patricknasser.com.br <www.patricknasser.com.br>`_


* Contains modifyed `Lincoln de Souza <https://github.com/clarete/pnad>`_ and `Carlos Góes <https://github.com/omercadopopular/cgoes/tree/master/TinyApps/pyPNAD>`_ code in pypnad.py